#!/bin/csh

echo MODULESANDSEED START:  `date +%s`
printf 'Job is running on node: '; /bin/hostname
printf 'Job submitted by: gilfoyle'
echo Running directory: `pwd`
set submissionID=$1
echo Directory `pwd` content before starting submissionID $submissionID':'
ls -l
if ($? != 0) then
  echo ls failure
  exit 211
endif

# Run Script Header
# -----------------
set echo
# limit core size
ulimit -c 10

# Exit if cvmfs not found
# -----------------
set cvmfsSetupFile = /cvmfs/oasis.opensciencegrid.org/jlab/hallb/clas12/soft/setup.csh
if (-f $cvmfsSetupFile ) then
		echo $cvmfsSetupFile exists
else
		echo CVMFS ERROR $cvmfsSetupFile does not exist. Exiting
		exit 202
endif

source /etc/profile.d/environment.csh
setenv RCDB_CONNECTION mysql://null

# numbers are hardcoded currently.
# In the future we could have uber modules

module unload coatjava
module unload jdk
module unload root
module unload mcgen

module load coatjava/6.5.9
module load jdk/1.8.0_31
module load root/6.22.06
module load mcgen/2.23

# lund file env needed by runGenerator phase
set lundFile     = $2

echo
generate-seeds.py generate
echo
echo MODULESANDSEED END:  `date +%s`
echo

# End of Run Script Header
# ------------------------


# Generator
# ---------

echo
echo LUND Event File: $lundFile
mv $lundFile lund.dat
echo

# End of Run Generator
# ---------------------


# Run GEMC
# --------

echo GEMC START:  `date +%s`

# copying the gcard to <conf>.gcard
cp /jlab/clas12Tags/$CLAS12TAG'/config/'rgb_fall2019'.gcard' rgb_fall2019.gcard

echo
echo GEMC executable: `which gemc`

gemc -USE_GUI=0 -OUTPUT='evio, gemc.evio' -N=10000 -INPUT_GEN_FILE='lund, lund.dat' rgb_fall2019.gcard  -SCALE_FIELD='TorusSymmetric, +1.00' -SCALE_FIELD='clas12-newSolenoid, -1.00'
if ($? != 0) then
	echo gemc failed
	echo removing data files and exiting
	rm -f *.hipo *.evio
	exit 204
endif
# removing generated events file
rm -f *.dat

echo
printf 'GEMC Completed on: '; /bin/date
echo
echo 'Directory Content After GEMC:'
ls -l
if ($? != 0) then
	echo ls failure
	echo removing data files and exiting
	rm -f *.hipo *.evio
	exit 211
endif
echo

echo GEMC END:  `date +%s`

# End of GEMC
# -----------



# Run evio2hipo
# -------------

echo EVIO2HIPO START:  `date +%s`

echo
printf 'Running evio2hipo with torus current scale: +1.00 and solenoid current scale: -1.00'
echo
echo
echo executing: evio2hipo -r 11 -t +1.00 -s -1.00 -i gemc.evio -o gemc.hipo
evio2hipo -r 11 -t +1.00 -s -1.00 -i gemc.evio -o gemc.hipo
if ($? != 0) then
	echo evio2hipo failed.
	echo removing data files and exiting
	rm -f *.hipo *.evio
	exit 205
endif

echo
printf 'evio2hipo Completed on: '; /bin/date
echo
echo 'Directory Content After evio2hipo:'
ls -l
if ($? != 0) then
	echo ls failure
	echo removing data files and exiting
	rm -f *.hipo *.evio
	exit 211
endif

echo EVIO2HIPO END:  `date +%s`

# End of evio2hipo
# ----------------



# Run Reconstruction
# ------------------

echo RECONSTRUCTION START:  `date +%s`

# copying the yaml file to recon.yaml
cp /jlab/clas12Tags/$CLAS12TAG'/config/'rgb_fall2019.yaml rgb_fall2019.yaml

set configuration = `echo YAML file: rgb_fall2019.yaml`
echo
df /cvmfs/oasis.opensciencegrid.org && df . && df /tmp
if ($? != 0) then
	echo df failure
	echo removing data files and exiting
	rm -f *.hipo *.evio
	exit 213
endif

echo
echo executing: recon-util -y rgb_fall2019.yaml -i gemc.hipo -o recon.hipo
recon-util -y rgb_fall2019.yaml -i gemc.hipo -o recon.hipo
if ($? != 0) then
	echo recon-util failed.
	echo removing data files and exiting
	rm -f *.hipo *.evio
	exit 207
endif
df /cvmfs/oasis.opensciencegrid.org && df . && df /tmp
if ($? != 0) then
	echo df failure
	echo removing data files and exiting
	rm -f *.hipo *.evio
	exit 213
endif

echo
printf 'recon-util Completed on: '; /bin/date
echo
echo 'Directory Content After recon-util:'
ls -l
if ($? != 0) then
	echo ls failure
	echo removing data files and exiting
	rm -f *.hipo *.evio
	exit 211
endif

hipo-utils -test recon.hipo
if ($? != 0) then
	echo hipo-utils failure
	echo removing data files and exiting
	rm -f *.hipo *.evio
	exit 214
endif

if (`stat -L -c%s recon.hipo` < 100) then
	echo hipo size failure
	echo removing data files and exiting
	rm -f *.hipo *.evio
	exit 215
endif

echo RECONSTRUCTION END:  `date +%s`

# End of Reconstruction
# ---------------------


# Removing Unnecessary Files and Creating DST if selected
# -------------------------------------------------------


echo Creating the DST
hipo-utils -filter -b 'RUN::*,RAW::epics,RAW::scaler,HEL::flip,HEL::online,REC::*,RECFT::*,MC::*' -merge -o dst.hipo recon.hipo
if ($? != 0) then
  echo hipo-utils failed.
  exit 208
endif



echo Additional cleanup
rm -f core*
rm -f *.gcard
rm -f recon.hipo
rm -f gemc.hipo
rm -f gemc.merged.hipo
rm -f *.evio
rm -f *.yaml
rm -f run.sh
rm -f nodeScript.sh
rm -f condor_exec.exe
rm -f RNDMSTATUS
rm -f random-seeds.txt
rm -f lund.dat

echo
echo nodeScript run completed.
echo

# End of Run Script Footer
# ------------------------

	
